# sail-client
Sail Client

Running:

```
python3 -m venv .env
.env/bin/python setup.py install
.env/bin/sail version
```

Add wheels and ship haha:

```
.env/bin/python setup.py bdist_wheel
.env/bin/twine upload dist/...
```
